from setuptools import setup

setup(name='random_paaakg',
      version='0.0',
      description='deskrrr',
      packages=['random_paaakg'],
      author_email='sonterkub@gmail.com',
      zip_safe=False)